================
kpireport-static
================

.. image:: https://img.shields.io/pypi/v/kpireport-static
   :target: https://pypi.org/project/kpireport-static

.. code-block::

   pip install kpireport-static
